==> haskell-rio-orphans-0.1.2.0-400-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio-orphans
version:              0.1.2.0
visibility:           public
id:                   rio-orphans-0.1.2.0-KEhwrFc6RsYAPOqwmmkn8P
key:                  rio-orphans-0.1.2.0-KEhwrFc6RsYAPOqwmmkn8P
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>

category:             Control
abi:                  ed89dbfa0025e8adc2e6cdf736780958
exposed:              True
exposed-modules:      RIO.Orphans
hidden-modules:       Paths_rio_orphans
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rio-orphans-0.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rio-orphans-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rio-orphans-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-orphans
hs-libraries:         HSrio-orphans-0.1.2.0-KEhwrFc6RsYAPOqwmmkn8P
depends:
    base-4.17.2.1 exceptions-0.10.5
    fast-logger-3.2.2-F99QlXKgzgG2boZw5kYhYP
    monad-control-1.0.3.1-Cs9DEjCH5Lv8Ysa7NCV3pS
    monad-logger-0.3.42-3TXdsX4FUg1JylYhfnFCyi
    resourcet-1.2.6-LvbunWgaFi52yDP9C6hdhe
    rio-0.1.22.0-DF5jw781s81J6ZHNxB3l7N
    transformers-base-0.4.6-81seU10hWeHFdsy7CHhbZu
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html:         /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-orphans-0.1.2.0-401-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio-orphans
version:              0.1.2.0
visibility:           public
id:                   rio-orphans-0.1.2.0-4T8mXx5m3NP3DoRMTvT8qx
key:                  rio-orphans-0.1.2.0-4T8mXx5m3NP3DoRMTvT8qx
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>

category:             Control
abi:                  e1d7e2b226da1f5fa74d633f9aef280f
exposed:              True
exposed-modules:      RIO.Orphans
hidden-modules:       Paths_rio_orphans
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rio-orphans-0.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rio-orphans-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rio-orphans-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-orphans
hs-libraries:         HSrio-orphans-0.1.2.0-4T8mXx5m3NP3DoRMTvT8qx
depends:
    base-4.17.2.1 exceptions-0.10.5
    fast-logger-3.2.2-F99QlXKgzgG2boZw5kYhYP
    monad-control-1.0.3.1-Cs9DEjCH5Lv8Ysa7NCV3pS
    monad-logger-0.3.42-3TXdsX4FUg1JylYhfnFCyi
    resourcet-1.2.6-LvbunWgaFi52yDP9C6hdhe
    rio-0.1.22.0-65HKKmirTI47zHW2ulAFEg
    transformers-base-0.4.6-81seU10hWeHFdsy7CHhbZu
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html:         /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
